@@ -16,7 +16,8 @@ def main():
     parser.add_argument('-f', '--file', type=str, dest='filename', help='The name of the file to convert', action='store', required=True)
     parser.add_argument('-s', '--scale', type=float, dest='scale', default=.1, help='The scale of the final dimensions', action='store')
     parser.add_argument('-w', '--width-stretch', type=float, dest='width_stretch', default=2, help='Scale which only applies to the width', action='store')
-    parser.add_argument('-g', '--gradient', type=str, dest='gradient', default='2', help='The gradient pattern which will be used', action='store')
+    parser.add_argument('-g', '--gradient', type=str, dest='gradient', default='0', help='The gradient pattern which will be used', action='store')
+    parser.add_argument('-r', '--fps', type=int, dest='fps', default=30, help='The FPS cap which will be used when viewing video and live video', action='store')
 
     args = parser.parse_args()
 
@@ -31,7 +32,7 @@ def main():
         except ValueError:
             source = 0
 
-        l = Live(source, scale=args.scale, w_stretch=args.width_stretch, gradient=args.gradient, fps=25, verbose=True)
+        l = Live(source, scale=args.scale, w_stretch=args.width_stretch, gradient=args.gradient, fps=args.fps, verbose=True)
 
         try:
             l.view()
@@ -40,18 +41,21 @@ def main():
         except Exception as e:
             print(f'ERROR (Please report this!): {e}')
             return
+        return
 
     elif args.filetype == 'video':
         c = Video(args.filename, scale=args.scale, w_stretch=args.width_stretch, gradient=args.gradient, verbose=True)
     else:
         c = Image(args.filename, scale=args.scale, w_stretch=args.width_stretch, gradient=args.gradient, verbose=True)
 
-    if args.filetype != 'live':
-        try:
-            c.convert()
+    try:
+        c.convert()
+        if args.filetype == 'video':
+            c.view(args.fps)
+        else:
             c.view()
-        except KeyboardInterrupt:
-            print('Exiting...')
+    except KeyboardInterrupt:
+        print('Exiting...')
 
 if __name__ == '__main__':
     main()
